# bower-pygments

This repository is for distribution on `bower`. The source for this module is in the [main Pygments repository](https://bitbucket.org/birkenfeld/pygments-main/). Please file issues and pull requests against that repository.
